PARAMETERS_BASE = [
    ("Precip", "Precipication"),
    ("AtTemp", "Atmospheric temperature"),
    ("AtPres", "Atmospheric pressure"),
    ("RelHumidity", "Relative humidity"),
    ("LeafWet", "Leaf wetness"),
    ("DewPoint", "Dew point"),
    ("WindSpeed", "Wind speed"),
    ("SoilMoisture", "Soil moisture"),
    ("SoilTemp", "Soil temperature"),
    ("GlobalRad", "Global radiation"),
]
