# Generated by Django 2.2.1 on 2019-06-21 15:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('measurements', '0005_serie_height'),
    ]

    operations = [
        migrations.AddField(
            model_name='station',
            name='status',
            field=models.CharField(choices=[('active', 'active'), ('decomissioned', 'decomissioned'), ('in maintenance', 'in maintenance')], default='active', max_length=255),
        ),
    ]
